==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/sk.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Activity feed for %1$s" : "Informačný kanál aktivity pre %1$s",
    "Activity feed" : "Prehľad aktivít",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Settings have been updated." : "Nastavenia boli aktualizované.",
    "remote user" : "vzdialený užívateľ",
    "Recent activity" : "Nedávna aktivita",
    "No activities" : "Žiadne aktivity",
    "More activities" : "Viac aktivít",
    "Daily activity summary for %s" : "Sumár dennej aktivity pre %s",
    "_and %n more…_::_and %n more…_" : ["a %n ďalší…","a %n ďalšie…","a %n ďalších…","a %n ďalších…"],
    "All activities" : "Všetky aktivity",
    "By others" : "Aktivity ostatných",
    "By you" : "Vlastné aktivity",
    "Activity at %s" : "Aktivita na %s",
    "Hello %s" : "Ahoj %s",
    "Hello %s," : "Ahoj %s,",
    "There was some activity at %s" : "Bola zaznamenaná aktivita u používateľa %s",
    "_and %n more _::_and %n more _" : ["a %n ďalší","a %n ďalšie","a %n ďalších","a %n ďalších"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Frekvenciu týchto e-mailov môžete zmeniť alebo ich zakázať v <a href=\"%s\"> nastaveniach </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Frekvenciu týchto e-mailov môžete zmeniť alebo ich zakázať v nastaveniach: %s",
    "Mail" : "Pošta",
    "Push" : "Vyskakovacie oznámenie",
    "Activity" : "Aktivita",
    "Notifications" : "Hlásenia",
    "This application enables people to view a log of activities about them, their files or other data." : "Táto aplikácia umožní používateľom prezerať záznam ich aktivít, aktivít práce so súbormi alebo inými dátami.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Táto aplikácia umožňuje ľuďom vidieť akcie súvisiace s ich súbormi a údajmi v Nextcloud.\n\t\tKaždá osoba si môže nakonfigurovať svoje individuálne nastavenia aktivity v osobných nastaveniach,\n\t\tvybrať, ktorá aktivita sa má preniesť na mobilné telefóny a odoslať e-mailom\n\t\talebo každé ráno posielať denný súhrn.\n\t\tViac informácií nájdete v dokumentácii k Aktivity.",
    "Send email" : "Odoslať email",
    "Send push notification" : "Odosielať push notifikácie",
    "Activity notification configuration" : "Konfigurácia upozornení na aktivity",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send activity emails" : "Odoslať emaily s aktivitou",
    "As soon as possible" : "Čo najskôr",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "You commented" : "Komentovali ste",
    "Message deleted by author" : "Správa vymazaná autorom",
    "Open {filename}" : "Otvoriť {filename}",
    "in {path}" : "v {path}",
    "Home" : "Domov",
    "Could not load activities" : "Aktivity sa nepodarilo načítať",
    "Loading activities" : "Načítavam aktivity",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd zobrazuje udalosti ako pridanie, zmeny a sprístupnenia",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "Loading more activities" : "Načítavam ďalšie aktivity",
    "No more activities." : "Žiadne ďalšie aktivity.",
    "Could not enable RSS link" : "Nepodarilo sa zapnúť RSS odkaz",
    "RSS link copied to clipboard" : "RSS odkaz bol skopírovaný do schránky",
    "Could not copy the RSS link, please copy manually:" : "Nepodarilo sa skopírovať RSS odkaz, skopírujte ho ručne:",
    "Activity settings" : "Nastavenia aktivity",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "RSS feed" : "RSS kanál",
    "Copy RSS feed link" : "Kopírovať odkaz na RSS kanál",
    "Personal notification settings" : "Osobné nastavenia upozornení",
    "Unable to load the activity list" : "Nie je možné načítať zoznam aktivít.",
    "Choose for which activities you want to get an email or push notification." : "Vyberte si, pre ktoré aktivity chcete dostávať e-maily alebo vyskakovacie oznámenia.",
    "Choose for which activities you want to get a push notification." : "Vyberte, pre ktoré aktivity chcete dostávať vyskakovacie upozornenia.",
    "Notification" : "Oznámenie",
    "Enable notification emails" : "Zapnúť upozorňovanie e-mailom",
    "Daily activity summary" : "Súhrn denných aktivít",
    "Send daily activity summary in the morning" : "Ráno mi pošlite denný súhrn aktivít",
    "Default settings" : "Predvolená nastavenia",
    "Configure the default notification settings for new accounts." : "Nastavte predvolené nastavenia upozornení pre nové účty.",
    "Unable to save the settings" : "Nepodarilo sa uložiť nastavenia",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/sk.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Activity feed for %1$s" : "Informačný kanál aktivity pre %1$s",
    "Activity feed" : "Prehľad aktivít",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Settings have been updated." : "Nastavenia boli aktualizované.",
    "remote user" : "vzdialený užívateľ",
    "Recent activity" : "Nedávna aktivita",
    "No activities" : "Žiadne aktivity",
    "More activities" : "Viac aktivít",
    "Daily activity summary for %s" : "Sumár dennej aktivity pre %s",
    "_and %n more…_::_and %n more…_" : ["a %n ďalší…","a %n ďalšie…","a %n ďalších…","a %n ďalších…"],
    "You can disable daily digest emails in the settings: %s" : "Môžete deaktivovať denné súhrnné e-maily v nastaveniach: %s",
    "All activities" : "Všetky aktivity",
    "By others" : "Aktivity ostatných",
    "By you" : "Vlastné aktivity",
    "Activity at %s" : "Aktivita na %s",
    "Hello %s" : "Ahoj %s",
    "Hello %s," : "Ahoj %s,",
    "There was some activity at %s" : "Bola zaznamenaná aktivita u používateľa %s",
    "_and %n more _::_and %n more _" : ["a %n ďalší","a %n ďalšie","a %n ďalších","a %n ďalších"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Frekvenciu týchto e-mailov môžete zmeniť alebo ich zakázať v <a href=\"%s\"> nastaveniach </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Frekvenciu týchto e-mailov môžete zmeniť alebo ich zakázať v nastaveniach: %s",
    "Mail" : "Pošta",
    "Push" : "Vyskakovacie oznámenie",
    "Activity" : "Aktivita",
    "Notifications" : "Hlásenia",
    "This application enables people to view a log of activities about them, their files or other data." : "Táto aplikácia umožní používateľom prezerať záznam ich aktivít, aktivít práce so súbormi alebo inými dátami.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Táto aplikácia umožňuje ľuďom vidieť akcie súvisiace s ich súbormi a údajmi v Nextcloud.\n\t\tKaždá osoba si môže nakonfigurovať svoje individuálne nastavenia aktivity v osobných nastaveniach,\n\t\tvybrať, ktorá aktivita sa má preniesť na mobilné telefóny a odoslať e-mailom\n\t\talebo každé ráno posielať denný súhrn.\n\t\tViac informácií nájdete v dokumentácii k Aktivity.",
    "Send email" : "Odoslať email",
    "Send push notification" : "Odosielať push notifikácie",
    "Activity notification configuration" : "Konfigurácia upozornení na aktivity",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send activity emails" : "Odoslať emaily s aktivitou",
    "As soon as possible" : "Čo najskôr",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "You commented" : "Komentovali ste",
    "Message deleted by author" : "Správa vymazaná autorom",
    "Open {filename}" : "Otvoriť {filename}",
    "in {path}" : "v {path}",
    "Home" : "Domov",
    "Could not load activities" : "Aktivity sa nepodarilo načítať",
    "Loading activities" : "Načítavam aktivity",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd zobrazuje udalosti ako pridanie, zmeny a sprístupnenia",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "Loading more activities" : "Načítavam ďalšie aktivity",
    "No more activities." : "Žiadne ďalšie aktivity.",
    "Could not enable RSS link" : "Nepodarilo sa zapnúť RSS odkaz",
    "RSS link copied to clipboard" : "RSS odkaz bol skopírovaný do schránky",
    "Could not copy the RSS link, please copy manually:" : "Nepodarilo sa skopírovať RSS odkaz, skopírujte ho ručne:",
    "Activity settings" : "Nastavenia aktivity",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "RSS feed" : "RSS kanál",
    "Copy RSS feed link" : "Kopírovať odkaz na RSS kanál",
    "Personal notification settings" : "Osobné nastavenia upozornení",
    "Unable to load the activity list" : "Nie je možné načítať zoznam aktivít.",
    "Choose for which activities you want to get an email or push notification." : "Vyberte si, pre ktoré aktivity chcete dostávať e-maily alebo vyskakovacie oznámenia.",
    "Choose for which activities you want to get a push notification." : "Vyberte, pre ktoré aktivity chcete dostávať vyskakovacie upozornenia.",
    "Notification" : "Oznámenie",
    "Enable notification emails" : "Zapnúť upozorňovanie e-mailom",
    "Daily activity summary" : "Súhrn denných aktivít",
    "Send daily activity summary in the morning" : "Ráno mi pošlite denný súhrn aktivít",
    "Default settings" : "Predvolená nastavenia",
    "Configure the default notification settings for new accounts." : "Nastavte predvolené nastavenia upozornení pre nové účty.",
    "Unable to save the settings" : "Nepodarilo sa uložiť nastavenia",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
